@@ -37,8 +37,6 @@
  * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
- *
- * $Id: imapurl.h,v 1.8 2008/03/24 17:43:09 murch Exp $
  */
 
 #ifndef IMAPURL_H
@@ -73,8 +71,8 @@ struct imapurl {
  *  mailbox should be about twice the length of src to deal with non-hex
  *  coded URLs; server should be as large as src.
  */
-int imapurl_fromURL(struct imapurl *url, const char *src);
-int URLtoMailbox(char *dst, char *src);
+extern int imapurl_fromURL(struct imapurl *url, const char *src);
+extern int URLtoMailbox(char *dst, const char *src);
 #define UTF8_to_mUTF7(dst, src) URLtoMailbox(dst, src)
 
 /* Convert an IMAP mailbox to a URL path
@@ -85,6 +83,6 @@ int URLtoMailbox(char *dst, char *src);
  *
  *  it is valid for mechname to be NULL (implies anonymous mech)
  */
-void imapurl_toURL(char *dst, struct imapurl *url);
+extern void imapurl_toURL(char *dst, const struct imapurl *url);
 
 #endif /* IMAPURL_H */
